# TC Laboratory Central_Management_System Client Module

## 简介

天创实验室中央管理程序Python端SDK

## CMS设计

### 简介

程序总共分为三个模块:

+ 文件访问
  
  + webdav协议
  
  + 下载/上传

+ 设备管理
  
  + 外部设备
  
  + 服务管理(基于Docker)
    
    + CMS插件区
    
    + 外部服务区

+ 权限系统

tclab-sdk设计与之一一对应.
